==> nextcloud-18.0.0-1-any.pkg.tar.xz: usr/share/webapps/nextcloud/apps/workflowengine/l10n/zh_TW.js <==
OC.L10N.register(
    "workflowengine",
    {
    "The given operator is invalid" : "指定的操作無效",
    "The given regular expression is invalid" : "指定的規則表達式無效",
    "The given file size is invalid" : "指定的檔案大小無效",
    "The given tag id is invalid" : "指定的標籤 Id無效",
    "The given IP range is invalid" : "指定的IP 範圍無效",
    "The given IP range is not valid for IPv4" : "指定的IP範圍不是有效的IPv4",
    "The given IP range is not valid for IPv6" : "指定的IP範圍不是有效的IPv6",
    "The given time span is invalid" : "指定的時間範圍無效",
    "The given start time is invalid" : "指定的開始時間無效",
    "The given end time is invalid" : "指定的結束時間無效",
    "The given group does not exist" : "指定的群組不存在",
    "File" : "檔案",
    "Operation #%s does not exist" : "操作 #%s 不存在",
    "Operation %s does not exist" : "操作 %s 不存在",
    "Operation %s is invalid" : "操作 #%s 無效",
    "Check %s does not exist" : "檢查 %s 不存在",
    "Check %s is invalid" : "檢查 %s 無效",
    "Check #%s does not exist" : "檢查 #%s 不存在",
    "Check %s is invalid or does not exist" : "檢查 %s 無效或不存在",
    "Images" : "圖片",
    "No results" : "沒有符合搜尋的項目",
    "%s (invisible)" : "%s （隱藏）",
    "%s (restricted)" : "%s （受限）",
    "Predefined URLs" : "預定義網址",
    "Files WebDAV" : "檔案 WebDAV",
    "Android client" : "Android 客戶端",
    "iOS client" : "iOS 客戶端",
    "Desktop client" : "桌面客戶端",
    "Cancel" : "取消",
    "Delete" : "刪除",
    "Active" : "啟動",
    "Save" : "儲存",
    "Browse the app store" : "瀏覽應用程式商店",
    "matches" : "匹配",
    "does not match" : "不能匹配",
    "is" : "是",
    "is not" : "不是",
    "File MIME type" : "檔案MIME類型",
    "File size (upload)" : "檔案大小(上傳)",
    "less" : "更少",
    "less or equals" : "小於或等於",
    "greater or equals" : "大於或等於",
    "greater" : "更大",
    "Request remote address" : "請求遠端地址",
    "matches IPv4" : "匹配 IPv4",
    "does not match IPv4" : "不能匹配 IPv4",
    "matches IPv6" : "匹配 IPv6",
    "does not match IPv6" : "不能匹配 IPv6",
    "File system tag" : "檔案系統標籤",
    "is tagged with" : "標記為",
    "is not tagged with" : "没有標記為",
    "Request URL" : "請求網址",
    "Request time" : "請求時間",
    "between" : "之間",
    "not between" : "皆非",
    "Request user agent" : "請求用戶代理",
    "User group membership" : "使用者成員關係",
    "is member of" : "是成員來自",
    "is not member of" : "不是成員來自",
    "Short rule description" : "簡短規則描述",
    "Add rule" : "添加規則",
    "Reset" : "重設",
    "Saving…" : "儲存中...",
    "Saved" : "已儲存",
    "Saving failed:" : "保存失敗:",
    "Add rule group" : "新增群組規則",
    "Example: {placeholder}" : "例子:{placeholder}",
    "Select tag…" : "選擇標籤",
    "Start" : "開始",
    "End" : "結束",
    "Select timezone…" : "選擇時區...",
    "Sync clients" : "同步客戶端",
    "Workflow" : "工作流程",
    "Open documentation" : "開啟說明文件",
    "Loading…" : "載入中…"
},
"nplurals=1; plural=0;");

==> nextcloud-20.0.4-1-any.pkg.tar.xz: usr/share/webapps/nextcloud/apps/workflowengine/l10n/zh_TW.js <==
OC.L10N.register(
    "workflowengine",
    {
    "The given operator is invalid" : "指定的操作無效",
    "The given regular expression is invalid" : "指定的規則表達式無效",
    "The given file size is invalid" : "指定的檔案大小無效",
    "The given tag id is invalid" : "指定的標籤 Id無效",
    "The given IP range is invalid" : "指定的IP 範圍無效",
    "The given IP range is not valid for IPv4" : "指定的IP範圍不是有效的IPv4",
    "The given IP range is not valid for IPv6" : "指定的IP範圍不是有效的IPv6",
    "The given time span is invalid" : "指定的時間範圍無效",
    "The given start time is invalid" : "指定的開始時間無效",
    "The given end time is invalid" : "指定的結束時間無效",
    "The given group does not exist" : "指定的群組不存在",
    "File" : "檔案",
    "Operation #%s does not exist" : "操作 #%s 不存在",
    "Operation %s does not exist" : "操作 %s 不存在",
    "Operation %s is invalid" : "操作 #%s 無效",
    "Check %s does not exist" : "檢查 %s 不存在",
    "Check %s is invalid" : "檢查 %s 無效",
    "Check #%s does not exist" : "檢查 #%s 不存在",
    "Check %s is invalid or does not exist" : "檢查 %s 無效或不存在",
    "Folder" : "資料夾",
    "Images" : "圖片",
    "No results" : "沒有符合搜尋的項目",
    "%s (invisible)" : "%s （隱藏）",
    "%s (restricted)" : "%s （受限）",
    "Predefined URLs" : "預定義網址",
    "Files WebDAV" : "檔案 WebDAV",
    "Android client" : "Android 客戶端",
    "iOS client" : "iOS 客戶端",
    "Desktop client" : "桌面客戶端",
    "Cancel" : "取消",
    "Delete" : "刪除",
    "Active" : "啟動",
    "Save" : "儲存",
    "Browse the app store" : "瀏覽應用程式商店",
    "matches" : "匹配",
    "does not match" : "不能匹配",
    "is" : "是",
    "is not" : "不是",
    "File MIME type" : "檔案MIME類型",
    "File size (upload)" : "檔案大小(上傳)",
    "less" : "更少",
    "less or equals" : "小於或等於",
    "greater or equals" : "大於或等於",
    "greater" : "更大",
    "Request remote address" : "請求遠端地址",
    "matches IPv4" : "匹配 IPv4",
    "does not match IPv4" : "不能匹配 IPv4",
    "matches IPv6" : "匹配 IPv6",
    "does not match IPv6" : "不能匹配 IPv6",
    "File system tag" : "檔案系統標籤",
    "is tagged with" : "標記為",
    "is not tagged with" : "没有標記為",
    "Request URL" : "請求網址",
    "Request time" : "請求時間",
    "between" : "之間",
    "not between" : "皆非",
    "Request user agent" : "請求用戶代理",
    "User group membership" : "使用者成員關係",
    "is member of" : "是成員來自",
    "is not member of" : "不是成員來自"
},
"nplurals=1; plural=0;");
